@@ -50,8 +50,8 @@ public:
 private:
     TwoFingerTapRecognizerPrivate *d;
 
-    virtual QGesture *create(QObject *) override;
-    virtual Result recognize(QGesture *, QObject *, QEvent *) override;
+    QGesture *create(QObject *) override;
+    Result recognize(QGesture *, QObject *, QEvent *) override;
 };
 
 } // namespace
